@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import base64
+import copy
 import json
 import os
 import platform
@@ -19,6 +20,8 @@ from django.utils.functional import Promise
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
 from django.contrib.admin.templatetags.admin_urls import add_preserved_filters
+from types import MappingProxyType
+
 
 register = template.Library()
 
@@ -192,41 +195,55 @@ def menus(context, _get_config=None):
     if config.get('dynamic', False) is True:
         config = _import_reload(_get_config('DJANGO_SETTINGS_MODULE')).SIMPLEUI_CONFIG
 
-    # app_list = context.get('app_list')
-    # for app in app_list:
-    #     _models = [
-    #         {
-    #             'name': m.get('name'),
-    #             'icon': get_icon(m.get('object_name'), unicode_to_str(m.get('name'))),
-    #             'url': m.get('admin_url'),
-    #             'addUrl': m.get('add_url'),
-    #             'breadcrumbs': [{
-    #                 'name': app.get('name'),
-    #                 'icon': get_icon(app.get('app_label'), app.get('name'))
-    #             }, {
-    #                 'name': m.get('name'),
-    #                 'icon': get_icon(m.get('object_name'), unicode_to_str(m.get('name')))
-    #             }]
-    #         }
-    #
-    #         for m in app.get('models')
-    #     ] if app.get('models') else []
-    #
-    #     module = {
-    #         'name': app.get('name'),
-    #         'icon': get_icon(app.get('app_label'), app.get('name')),
-    #         'models': _models
-    #     }
-    #     data.append(module)
+    config = copy.deepcopy(config)
 
-    # 如果有menu 就读取，没有就调用系统的
-    key = 'system_keep'
+    # 获取django所有app的models
+    app_list = context.get('app_list')
+    for app in app_list:
+        _models = [
+            {
+                'name': m.get('name'),
+                'icon': get_icon(m.get('object_name'), unicode_to_str(m.get('name'))),
+                'url': m.get('admin_url'),
+                'addUrl': m.get('add_url'),
+                'breadcrumbs': [{
+                    'name': app.get('name'),
+                    'icon': get_icon(app.get('app_label'), app.get('name'))
+                }, {
+                    'name': m.get('name'),
+                    'icon': get_icon(m.get('object_name'), unicode_to_str(m.get('name')))
+                }]
+            }
+
+            for m in app.get('models')
+        ] if app.get('models') else []
+
+        module = {
+            'name': app.get('name'),
+            'icon': get_icon(app.get('app_label'), app.get('name')),
+            'models': _models
+        }
+        data.append(module)
+
+    # 如果有配置自定义menu就读取自定义的，没有就调用系统的
     if config and 'menus' in config:
-        if config.get(key, None):
-            temp = config.get('menus')
+        # 如果'system_keep'!=True，则清空系统的菜单
+        if not config.get('system_keep', None):
+            data = []
+
+        # 读取自定义菜单
+        temp = config.get('menus')
+        # 如果是超级管理员则拥有所有菜单
+        if context.request.user.is_superuser:
+            for i in temp:
+                data.append(i)
+
+        # 根据权限配置删除菜单
+        else:
+            # 获取权限列表
             groups_permissions = context.request.user.get_group_permissions()
             for i in temp:
-                # check level 1 menu
+                # 检查1级菜单
                 if 'codename' not in i \
                         or (True in [(True if i['codename'] in g_p else False)
                                      for g_p in groups_permissions]) == False:
@@ -256,16 +273,16 @@ def menus(context, _get_config=None):
                             'icon': k.get('icon')
                         }]
                     for del_m in delete_models:
+                        print('delete: %s' % del_m)
                         i['models'].remove(del_m)
                 else:
                     i['breadcrumbs'] = [{
                         'name': i.get('name'),
                         'icon': i.get('icon')
                     }]
-                # if len(i[models]) > 0:
                 data.append(i)
-        else:
-            data = config.get('menus')
+    else:
+        data = config.get('menus')
 
     # 获取侧边栏排序, 如果设置了就按照设置的内容排序, 留空则表示默认排序以及全部显示
     if config.get('menu_display') is not None:
@@ -276,28 +293,29 @@ def menus(context, _get_config=None):
             _app['_weight'] = config.get('menu_display').index(_app['name'])
             display_data.append(_app)
 
-        # if config.get('menu_display') is not None:
-        #     display_data = list()
-        #     for _app in data:
-        #         if _app['name'] not in config.get('menu_display'):
-        #             continue
-        #         # check level 2
-        #         if _app.get('menu_display') is not None:
-        #             display_model = list()
-        #             for _app_m in _app['models']:
-        #                 if _app_m['name'] not in _app.get('menu_display'):
-        #                     continue
-        #                 _app_m['_weight'] = _app.get('menu_display').index(_app_m['name'])
-        #                 display_model.append(_app_m)
-        #         else:
-        #             display_model = _app['models']
-        #
-        #         _app['models'] = display_model
-        #         _app['_weight'] = config.get('menu_display').index(_app['name'])
-        #         display_data.append(_app)
-
-        display_data.sort(key=lambda x: x['_weight'])
-        data = display_data
+    # if config.get('menu_display') is not None:
+    #     display_data = list()
+    #     for _app in data:
+    #         if _app['name'] not in config.get('menu_display'):
+    #             continue
+    #         # check level 2
+    #         if _app.get('menu_display') is not None:
+    #             display_model = list()
+    #             for _app_m in _app['models']:
+    #                 if _app_m['name'] not in _app.get('menu_display'):
+    #                     continue
+    #                 _app_m['_weight'] = _app.get('menu_display').index(_app_m['name'])
+    #                 display_model.append(_app_m)
+    #         else:
+    #             if 'models' in _app.keys():
+    #                 display_model = _app['models']
+    #
+    #         _app['models'] = display_model
+    #         _app['_weight'] = config.get('menu_display').index(_app['name'])
+    #         display_data.append(_app)
+    #
+    #     display_data.sort(key=lambda x: x['_weight'])
+    #     data = display_data
 
     # 给每个菜单增加一个唯一标识，用于tab页判断
     eid = 1000
